cmake_minimum_required(VERSION 3.23)

if(NOT TARGET sirius::sirius_cxx)
  # Find bundled modules first
  set(CMAKE_MODULE_PATH "${CMAKE_CURRENT_LIST_DIR}/modules" ${CMAKE_MODULE_PATH})

  # store CXX compiler id. Used in MKL package.
  set(SIRIUS_CXX_COMPILER_ID Clang)
  if(NOT ${CMAKE_CXX_COMPILER_ID})
    set(CMAKE_CXX_COMPILER_ID ${SIRIUS_CXX_COMPILER_ID})
  endif()

  # if not relocatable
  if (NOT NO)
    set(MPI_ROOT )
    set(ENV{SPG_DIR} )
    set(ENV{LIBXCROOT} )
    set(ENV{GSL_ROOT_DIR} )
    set(ENV{MKLROOT} )
    set(ENV{MAGMAROOT} )
    set(ENV{ELPAROOT} )
    set(SpFFT_DIR /usr/local/lib/cmake/SpFFT)
    # TODO: CUDA, ROCM, mpi4py ?
  endif()

  # pass REQUIRED or QUIET depending on top Config call
  if (sirius_cxx_FIND_REQUIRED)
    set(mode REQUIRED)
  else()
    set(mode QUIET)
  endif()

  find_dependency(MPI ${mode} COMPONENTS CXX)
  find_dependency(GSL ${mode})
  find_dependency(LibXC 3.0.0 ${mode})
  find_dependency(LibSPG ${mode})
  find_dependency(HDF5 ${mode} C)
  include("${CMAKE_CURRENT_LIST_DIR}/hdf5_target.cmake")
  find_dependency(SpFFT 0.9.6 CONFIG ${mode})
  find_dependency(SPLA 1.1.0 CONFIG ${mode})
  find_dependency(costa CONFIG ${mode})

  if(ON)
    find_dependency(OpenMP ${mode})
  endif()

  if(OFF)
    set(MKL_INTERFACE "")
    set(MKL_THREADING "")
    set(MKL_MPI "")
    find_dependency(MKL CONFIG)
  elseif(OFF)
    find_dependency(CRAY_LIBSCI ${mode})
  else()
    find_dependency(LAPACK ${mode})
    if(OFF)
      find_dependency(SCALAPACK ${mode}) # just sets scalapack_DIR
    endif()
  endif()

  if(OFF)
    find_dependency(Elpa ${mode})
  endif()

  if(OFF)
    find_dependency(DLAF ${mode})
  endif()

  if(OFF)
    find_dependency(MAGMA ${mode})
  endif()

  if(OFF)
    find_dependency(LibVDWXC 0.3.0 ${mode})
  endif()

  if(OFF)
    # TODO: propagate the passed `sm` flag
    find_dependency(CUDA ${mode})
    include("${CMAKE_CURRENT_LIST_DIR}/cudalibs_target.cmake")
  endif()

  if(OFF)
    find_dependency(hip CONFIG ${mode})
    find_dependency(rocblas CONFIG ${mode})
    find_dependency(rocsolver CONFIG ${mode})
  endif()

  if(OFF)
    find_dependency(umpire ${mode})
  endif()

  if(OFF)
    find_dependency(pugixml ${mode})
  endif()

  # Clean-up module path.
  list(REMOVE_ITEM CMAKE_MODULE_PATH "${CMAKE_CURRENT_LIST_DIR}/modules")

  # Include SIRIUS target
  include("${CMAKE_CURRENT_LIST_DIR}/sirius_cxxTargets.cmake")
endif()
